@@ -6,7 +6,7 @@
  * compiled with exif support), the Exiftool package (more complete but slower),
  * or the bundled exif library.
  *
- * Copyright 2003-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2003-2014 Horde LLC (http://www.horde.org/)
  *
  * @author Michael J. Rubinsky <mrubinsk@horde.org>
  * @author Chuck Hagenbuch <chuck@horde.org>
@@ -15,6 +15,20 @@
  */
 class Horde_Image_Exif
 {
+    static protected $_titleFields = array(
+        'IPTC' => array('ObjectName'),
+        'XMP'  => array('Title'),
+        'EXIF' => array(),
+        'COMPOSITE' => array()
+    );
+
+    static protected $_descriptionFields = array(
+        'IPTC' => array('Caption-Abstract'),
+        'XMP'  => array('Description'),
+        'EXIF' => array('ImageDescription'),
+        'COMPOSITE' => array()
+    );
+
     /**
      * Factory method for instantiating a Horde_Image_Exif object.
      *
@@ -78,7 +92,9 @@ class Horde_Image_Exif
             'XMP' => array(
                 'Creator' => array('description' => Horde_Image_Translation::t("Image Creator"), 'type' => 'text'),
                 'Rights' => array('description' => Horde_Image_Translation::t("Rights"), 'type' => 'text'),
-                'UsageTerms' => array('description' => Horde_Image_Translation::t("Usage Terms"), 'type' => 'type'),
+                'UsageTerms' => array('description' => Horde_Image_Translation::t("Usage Terms"), 'type' => 'text'),
+                'Title' => array('description' => Horde_Image_Translation::t("Title"), 'type' => 'text'),
+                'Description' => array('description' => Horde_Image_Translation::t("Description"), 'type' => 'text'),
             ),
 
             'EXIF' => array(
@@ -132,11 +148,81 @@ class Horde_Image_Exif
         );
     }
 
+    /**
+     * Return a list of metadata fields that can by used for image titles.
+     *
+     * @param mixed $driver  A Horde_Image_Exif_Base instance or a string
+     *                       specifying the driver in use.
+     *
+     * @return array  An array of metadata field name hashes.
+     * @since 2.1.0
+     */
+    static public function getTitleFields($driver = null)
+    {
+        if (!is_null($driver) && is_array($driver)) {
+            $driver = self::factory($driver[0], $driver[1]);
+        }
+        if ($driver instanceof Horde_Image_Exif_Base) {
+            $supported = $driver->supportedCategories();
+        } else {
+            $supported = array('XMP', 'IPTC', 'EXIF');
+        }
+
+        $fields = array();
+        foreach ($supported as $category) {
+            $fields = array_merge($fields, self::$_titleFields[$category]);
+        }
+        $return = array();
+        $all = self::getFields($driver, true);
+        foreach ($fields as $field) {
+            $return[$field] = $all[$field];
+        }
+
+        return $return;
+    }
+
+    /**
+     * Return a list of metadata fields that can by used for image descriptions.
+     *
+     * @param mixed $driver  A Horde_Image_Exif_Base instance or a string
+     *                       specifying the driver in use.
+     *
+     * @return array  An array of metadata field hashes.
+     * @since 2.1.0
+     */
+    static public function getDescriptionFields($driver = null)
+    {
+        $map = self::getCategories();
+        if (!is_null($driver) && is_array($driver)) {
+            $driver = self::factory($driver[0], $driver[1]);
+        }
+        if ($driver instanceof Horde_Image_Exif_Base) {
+            $supported = $driver->supportedCategories();
+        } else {
+            $supported = array('XMP', 'IPTC', 'EXIF');
+        }
+
+        $fields = array();
+        foreach ($supported as $category) {
+            $fields = array_merge($fields, self::$_descriptionFields[$category]);
+        }
+        $return = array();
+        $all = self::getFields($driver, true);
+        foreach ($fields as $field) {
+            $return[$field] = $all[$field];
+        }
+
+        return $return;
+    }
+
     /**
      * Return a flattened array of supported metadata fields.
      *
-     * @param $driver
-     * @return unknown_type
+     * @param mixed $driver  A Horde_Image_Exif_Base instance or a string
+     *                       specifying the driver in use.
+     * @param boolean $description_only  Only return the field descriptions.
+     *
+     * @return array
      */
     static public function getFields($driver = null, $description_only = false)
     {
@@ -388,7 +474,7 @@ class Horde_Image_Exif
             break;
 
         case 'LightSource':
-            switch ($data) {;
+            switch ($data) {
             case 1: return Horde_Image_Translation::t("Daylight");
             case 2: return Horde_Image_Translation::t("Fluorescent");
             case 3: return Horde_Image_Translation::t("Tungsten");
