@@ -2,7 +2,7 @@
 /**
  * Imagick driver for the Horde_Image API
  *
- * Copyright 2007-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -275,7 +275,7 @@ class Horde_Image_Imagick extends Horde_Image_Base
     public function grayscale()
     {
         try {
-            $this->_imagick->setImageColorSpace(Imagick::COLORSPACE_GRAY);
+            $this->_imagick->setImageType(Imagick::IMGTYPE_GRAYSCALE);
         } catch (ImageException $e) {
             throw new Horde_Image_Exception($e);
         }
